@@ -1,4 +1,5 @@
-lm.correctSE <- function(model)
+lm.correctSE <- function(model, digits=3)
+#2011-02-27:  added digits as a parameter
 {
   newSEs = sqrt(diag(hccm(model)))
   modelsum = summary(model)
@@ -8,7 +9,7 @@ lm.correctSE <- function(model)
   thetable[,4] = 2*(pt(abs(thetable[,3]), df=modelsum$df[2], lower.tail=FALSE))
 
   cat('Uncorrected Tests of Coefficients\n\n')
-  print(modelsum$coefficients)
+  print(modelsum$coefficients, digits=digits)
   cat('\nWhite (1980) Heteroscedascity-corrected SEs and Tests\n\n')
-  print(thetable)
+  print(thetable, digits=digits)
 }
\ No newline at end of file
